@@ -12,16 +12,27 @@ from ortools.constraint_solver import pywrapcp
 def test_func():
     return math.inf
 
+@njit
+def LS( giant_tour,DM_req, iteration_num=0):
+    # DM_req =  self.DM_req
+    print(giant_tour[1])
+    for k in range(10):
+        for i in range(1,len(giant_tour)-2):
+            if DM_req[giant_tour[i-1]][giant_tour[i]]+ DM_req[giant_tour[i+2]][giant_tour[i+1]]>  DM_req[giant_tour[i-1]][giant_tour[i+1]]+ DM_req[giant_tour[i]][giant_tour[i+2]]:
+                x= giant_tour[i+1]
+                giant_tour[i+1]=giant_tour[i]
+                giant_tour[i] =x
+    return giant_tour
+
 class GT:
-    def __init__(self, DM_req, size_of_clusters, number_of_depots):
+    def __init__(self, DM_req, size_of_clusters):
         self.DM_req = DM_req
         self.size_of_clusters = size_of_clusters
-        self.number_of_depots = number_of_depots
 
     def total_clustering(self, DM_req, size_of_clusters):
         # DM_req, number_of_clusters, small_cluster_num
-        DM_req = self.DM_req
-        size_of_clusters = self.size_of_clusters
+        # DM_req = self.DM_req
+        # size_of_clusters = self.size_of_clusters
 
         def fasterpam(small_list_req, DM_req, number_cluster):
             n_DM_req = len(small_list_req)
@@ -301,88 +312,6 @@ class GT:
                 giant_tour.append(trip[0])
         return giant_tour
 
-    def draw_cluster_result(self, number_of_depots, cluster_result, center_point=[], GT_between_cluster=[], in_out_original=[],
-                            giant_tour=[]):
-
-        from matplotlib.pyplot import figure
-        figure(figsize=(8, 8), dpi=80)
-        plt.plot(1000, 1000, "bo")
-
-        for i in range(len(cluster_result)):
-            for point in cluster_result[i]:
-                p = point + number_of_depots
-                print
-                plt.plot(location[p][0], location[p][1], color_list[i % len(color_list)], marker="o", alpha=1)
-                plt.text(location[p][0], location[p][1], str(p))
-
-        for point in center_point:
-            p = point + number_of_depots
-            plt.plot(location[p][0], location[p][1], color="pink", marker="^")
-
-        print("GT_between_cluster", GT_between_cluster)
-        X = []
-        Y = []
-        for item in GT_between_cluster:
-            p = center_point[item] + number_of_depots
-            X.append(location[p][0])
-            Y.append(location[p][1])
-        plt.plot(X, Y, 'k', alpha=0.1)
-
-        X = []
-        Y = []
-        for i in range(len(in_out_original)):
-            p = in_out_original[i][1] + number_of_depots
-            X.append(location[p][0])
-            Y.append(location[p][1])
-            p = in_out_original[(i + 1) % len(in_out_original)][0] + number_of_depots
-            X.append(location[p][0])
-            Y.append(location[p][1])
-        plt.plot(X, Y, 'b', alpha=0.5)
-        print(giant_tour)
-        X = []
-        Y = []
-        for i in range(len(giant_tour)):
-            p = giant_tour[i] + number_of_depots
-            X.append(location[p][0])
-            Y.append(location[p][1])
-        plt.plot(X, Y, 'r', alpha=1)
-
-    def create_draw_giant_tour(self, number_of_depots):
-        DM_req = self.DM_req
-        size_of_clusters = self.size_of_clusters
-        cluster_result = self.total_clustering(DM_req, size_of_clusters)
-        print("cluster_result", cluster_result)
-
-        center_point = self.create_center_point(cluster_result, DM_req)
-        print("center_point", center_point)
-
-        DM_center = self.create_distance_matrix_center_point(center_point, DM_req)
-        DM_center
-        GT_between_cluster = \
-        self.create_route_of_cluster(self.create_data_model_for_center_points(DM_center, center_point, 0))[0]
-        GT_between_cluster = GT_between_cluster[:-1]
-
-        GT_cluster_list = [cluster_result[i] for i in GT_between_cluster]
-
-        plt.show()
-        in_out = self.create_in_out(GT_cluster_list, DM_req)
-        in_out_original = np.empty((len(GT_between_cluster), 2), np.int_)
-        print(in_out)
-        for i in range(len(in_out)):
-            in_out_original[i][0] = GT_cluster_list[i][in_out[i][0]]
-            in_out_original[i][1] = GT_cluster_list[i][in_out[i][1]]
-        for item in in_out_original:
-            print(item[0] + number_of_depots, item[1] + number_of_depots)
-
-        # r(self, GT_cluster_list, DM_req, in_out)
-        giant_tour = self.find_giant_tour(GT_cluster_list, DM_req, in_out)
-
-        giant_tour = LS(np.array(giant_tour, np.int_), DM_req, 5)
-        self.draw_cluster_result(cluster_result, center_point, GT_between_cluster, in_out_original, giant_tour)
-
-        self.giant_tour = np.array(giant_tour, np.int_)
-        return giant_tour
-
     def create_giant_tour(self):
         DM_req = self.DM_req
         size_of_clusters = self.size_of_clusters
@@ -416,7 +345,8 @@ class GT:
         self.giant_tour = np.array(giant_tour, np.int_)
         return giant_tour
 
-    def help():
+    def help(self):
         text = " this program computes a giant tour formed by a Distant Matrix, and a number of approximate cluster size."
         text += "giant_tour_problem = GT(distant matrix, size of cluster). Output is a giant tour, in form of a list"
+        text += "giant_tour_problem = gt.GT(DM_req,size_of_clusters= 6), s = giant_tour_problem.create_giant_tour()"
         print(text)
\ No newline at end of file
